Getting Help
=============

Donations
----------

On github, the NPO run funding options are US/EU centric. Not a user of: stripe,
paypal, or advocate of bank transfer.

All paths lead to bleeding privacy information. It's possible for a
company or individual to receive funds and process it thru a tax authority.

Ensuring this is not the responsibility of the sponsor. That burden is
on the receiver.

Wallets
""""""""

Litecoin: ltc1qeaed7g28kqpzpqfyrns6n3p5jcy2fhjwu5wdpg

Dogecoin: DKc178z1uezL73z9nZwPdpFLwwhiSm1QZk

Consulting
------------

Package support

.. csv-table:: Global Services
   :header: title, description
   :widths: auto

   "Dependency lock on/off switch", "package dependency requirement files, both .lock/.unlock files, howto.txt, pyproject.toml"
   "Automate changelog", "Setup change log, NOTICE.txt, Sphinx conf.py. One Makefile command to create initialize change log entry"
   "Sphinx TOC setup", ".md and .rst support, table of contents, well thought out outline structure"

Not saying what local means

.. csv-table:: Local Service
   :header: title, description
   :widths: auto

   "Android Burner phone", "Connect to personal phone wifi. Make payments at supported local stores"

Contact
----------

If a cryptocurrency is not listed `send a message <https://mastodon.social/@msftcangoblowme>`_
